@@ -13,92 +13,6 @@ import quandl
 import talib
 from cryptotoolbox.risk_metrics import riskmetrics
 
-#####
-#core_tokens = ['BTC','ETH']
-#extra_tokens = ['AVAX','TRX','SOL','MATIC','PAXG']
-
-#core_tokens = ['BTC','ETH']
-#extra_tokens = ['PAXG']
-
-core_tokens = ['BTC','ETH']
-extra_tokens = []
-
-
-#core_tokens = ['BTC','PAXG']
-#extra_tokens = []
-
-#extra_tokens = []
-
-local_root_directory = '/Users/stefanduprey/Documents/My_Data/My_AdvancedFlagship/'
-
-
-daily_crypto_starting_date_string = '2017-01-01'
-#daily_crypto_starting_day = '2019-01-01'
-daily_crypto_starting_date = datetime.strptime(daily_crypto_starting_date_string, '%Y-%m-%d')
-starting_date = daily_crypto_starting_date
-running_date = datetime.now()
-
-dates_stub = starting_date.strftime('%d_%b_%Y') + '_' + running_date.strftime('%d_%b_%Y')
-
-
-frequence = 'Frequency.DAILY'
-ssj_against = 'USDT'
-
-rebalancing_day = 5
-write_excel_file = True
-
-send_to_production = False
-plot_metrics = True
-plotHtmlAndSave = True
-
-reaggregate = False
-if reaggregate:
-    aggregated_df = alpha.aggregate_alpha_signal(daily_crypto_starting_date=daily_crypto_starting_date,
-                                           daily_crypto_ending_date = running_date,
-                                           ssj_against = ssj_against,
-                                           core_tokens = core_tokens,
-                                           extra_tokens = extra_tokens,
-                                           frequence = 'Frequency.DAILY',
-                                           local_root_directory=local_root_directory,
-                                           refetch_pricing=True)
-    aggregated_df.to_pickle(local_root_directory + f'{dates_stub}lobasissaggregated_df.pkl')
-else :
-    aggregated_df= pd.read_pickle(local_root_directory + f'{dates_stub}lobasissaggregated_df.pkl')
-
-print('done')
-
-if reaggregate:
-    hourly_aggregated_df = None
-    for me_symb in core_tokens + extra_tokens:
-        print(f'requesting hourly prices {me_symb}')
-        try:
-            data_df = crypto_connector.fetch_crypto_hourly_data(ssj=me_symb, local_root_directory=local_root_directory,
-                                                             hourly_return_pkl_filename_suffix='hourly_coin_investigation.pkl',
-                                                             refetch_all=True,
-                                                             daily_crypto_starting_day=daily_crypto_starting_date,
-                                                             daily_crypto_ending_day=running_date)
-            data_df = data_df.rename(columns={'close': f'close_{me_symb}'})
-            data_df = data_df.rename(columns={'open':  f'open_{me_symb}'})
-            data_df = data_df.rename(columns={'high':  f'high_{me_symb}'})
-            data_df = data_df.rename(columns={'low':  f'low_{me_symb}'})
-            data_df = data_df.rename(columns={'volumeto':  f'volume_{me_symb}'})
-            data_df = data_df.rename(columns={'volume':  f'volume_{me_symb}'})
-
-            data_df = data_df.replace(0,np.nan)
-            data_df = data_df[[f'close_{me_symb}',f'open_{me_symb}',f'high_{me_symb}',f'low_{me_symb}',f'volume_{me_symb}']]
-            if hourly_aggregated_df is None:
-                hourly_aggregated_df = data_df.copy()
-            else:
-                hourly_aggregated_df = pd.merge(hourly_aggregated_df.copy(), data_df.copy(), left_index=True, right_index=True)
-            print(f'aggregated size {me_symb} {hourly_aggregated_df.shape}')
-        except Exception as e:
-            print(f'trouble {e}')
-            print(f'failin {me_symb}')
-
-    hourly_aggregated_df.to_pickle(local_root_directory + f'{dates_stub}rsilobasissaggregated_df.pkl')
-else:
-    hourly_aggregated_df = pd.read_pickle(local_root_directory + f'{dates_stub}rsilobasissaggregated_df.pkl')
-
 
 def strat_weekly(y, btc='BTC', tone=14,ttwo=23,p1=1.01, p2=1.05, long_expo=1., short_expo=0., rebalancing_day=5):  # On rentre le dataframe
     weekday = y.weekday.values
